pub struct EntryMetadata {
pub size: u64,
pub modified: u64,
pub accessed: u64,
pub created: u64,
pub is_dir: bool,
pub is_file: bool,
pub is_symlink: bool,
pub permissions: u32,
pub uid: u32,
pub gid: u32,
}Fields
size: u64modified: u64accessed: u64created: u64is_dir: boolis_file: boolis_symlink: boolpermissions: u32uid: u32gid: u32Trait Implementations
Sourceimpl Clone for EntryMetadata
impl Clone for EntryMetadata
Sourcefn clone(&self) -> EntryMetadata
fn clone(&self) -> EntryMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntryMetadata
impl Debug for EntryMetadata
Sourceimpl Default for EntryMetadata
impl Default for EntryMetadata
Sourceimpl From<EntryMetadata> for EntryMetadata
impl From<EntryMetadata> for EntryMetadata
Sourcefn from(meta: EntryMetadata) -> Self
fn from(meta: EntryMetadata) -> Self
Converts to this type from the input type.
Sourceimpl From<EntryMetadata> for EntryMetadata
impl From<EntryMetadata> for EntryMetadata
Sourcefn from(meta: EntryMetadata) -> Self
fn from(meta: EntryMetadata) -> Self
Converts to this type from the input type.
Sourceimpl Message for EntryMetadata
impl Message for EntryMetadata
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EntryMetadata
impl PartialEq for EntryMetadata
Sourcefn eq(&self, other: &EntryMetadata) -> bool
fn eq(&self, other: &EntryMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EntryMetadata